16.63. cdist-type__install_chroot_mount(7) — cdist 6.9.4 documentation

# 16.63. cdist-type__install_chroot_mount(7)

## 16.63.1. NAME

cdist-type__install_chroot_mount - mount a chroot with install command

## 16.63.2. DESCRIPTION

Mount and prepare a chroot for running commands within it.

## 16.63.3. REQUIRED PARAMETERS

None

## 16.63.4. OPTIONAL PARAMETERS

None

## 16.63.5. EXAMPLES

    __install_chroot_mount /path/to/chroot

## 16.63.6. AUTHORS

Steven Armstrong <steven-cdist--@--armstrong.cc>

## 16.63.7. COPYING

Copyright (C) 2012 Steven Armstrong. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.